@@ -124,10 +124,10 @@ namespace giac {
 
   matrice companion(const vecteur & w);
   gen a_root(const vecteur & v,const std::complex<double> & c0,double eps);
-  vecteur proot(const vecteur & v);
-  vecteur proot(const vecteur & v,double eps);
-  vecteur proot(const vecteur & v,double & eps,int & rprec);
-  vecteur real_proot(const vecteur & v,double eps,GIAC_CONTEXT);
+  vecteur proot(const vecteur & v,GIAC_CONTEXT0);
+  vecteur proot(const vecteur & v,double eps,GIAC_CONTEXT0);
+  vecteur proot(const vecteur & v,double & eps,int & rprec,GIAC_CONTEXT0);
+  vecteur real_proot(const vecteur & v,double eps,GIAC_CONTEXT0);
   gen symb_proot(const gen & e) ;
   gen _proot(const gen & e,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_proot ;
@@ -390,8 +390,8 @@ namespace giac {
   vecteur mpcar_int(const matrice & A,bool krylov,GIAC_CONTEXT,bool compute_pmin);
 
   void mod_pcar(std_matrix<gen> & N,vecteur & res,bool compute_pmin);
-  bool mod_pcar(const matrice & A,std::vector< std::vector<int> > & N,int modulo,bool & krylov,std::vector<int> & res,GIAC_CONTEXT,bool compute_pmin);
-  bool mod_pcar(std::vector< std::vector<int> > & N,int modulo,bool & krylov,std::vector<int> & res,GIAC_CONTEXT,bool compute_pmin);
+  bool mod_pcar(const matrice & A,std::vector< std::vector<int> > & N,int modulo,bool & krylov,std::vector<int> & res,GIAC_CONTEXT,bool compute_pmin,std::vector< std::vector<int> > & ttemp);
+  bool mod_pcar(std::vector< std::vector<int> > & N,int modulo,bool & krylov,std::vector<int> & res,GIAC_CONTEXT,bool compute_pmin,std::vector< std::vector<int> > & ttemp);
   vecteur mpcar_hessenberg(const matrice & A,int modulo,GIAC_CONTEXT);
   gen _pcar_hessenberg(const gen & g,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_pcar_hessenberg ;
@@ -500,7 +500,7 @@ namespace giac {
 #endif
   // LDL decomposition, inertia computation and solve_indef for fast system solving using the factorization
   bool ldl(matrice & a,std::vector<int> & perm,int mat_type,bool &sing,double time_limit,GIAC_CONTEXT);
-#ifdef HAVE_LIBLAPACK
+#if defined(HAVE_LIBLAPACK) && !defined(POCKETCAS)
   bool solve_indef(double *A,double **WORK,int *IPIV,double *b,int N,int NRHS,int *p,int *n,int *z);
 #endif
   bool solve_indef(matrice &A,const vecteur *b,vecteur &x,int *p,int *n,int *z,GIAC_CONTEXT);
